@@ -1,14 +1,17 @@
 # Wrapper for search functions vertsearch, searchbyterm, spatialsearch and bigsearch
 
-vertwrapper <- function(fxn = "", args = NULL, lim = NULL, rfile = NULL, email = NULL,
-                        compact = TRUE, verbose = TRUE, ...){
-  mssg(verbose, "Processing request...")
+vertwrapper <- function(fxn = "", args = NULL, lim = NULL, rfile = NULL, 
+                        email = NULL, compact = TRUE, messages = TRUE, 
+                        only_dwc = TRUE, callopts = list(), ...) {
+  mssg(messages, "Processing request...")
   if (fxn == "bigsearch") {
-    tt <- GET(vdurl(), query = list(q = make_bigq(args, email, rfile)), ...)
-    stop_for_status(tt)
-    mssg(verbose, "\nThank you! Download instructions will be sent by email.")
+    #tt <- GET(vdurl(), query = list(q = make_bigq(args, email, rfile)), ...)
+    cli <- crul::HttpClient$new(url = vdurl(), opts = callopts)
+    tt <- cli$get('api/download', query = list(q = make_bigq(args, email, rfile)), ...)
+    tt$raise_for_status()
+    mssg(messages, "\nThank you! Download instructions will be sent by email.")
   } else {
-    ress <- vert_GET(fxn, args, lim, verbose, ...)
+    ress <- vert_GET(fxn, args, lim, messages, only_dwc, callopts, ...)
     
     # Remove columns populated fully by NAs
     if (compact) { 
@@ -19,9 +22,9 @@ vertwrapper <- function(fxn = "", args = NULL, lim = NULL, rfile = NULL, email =
     # Return results
     if (NROW(ress$data) == 0) {
       NULL
-      mssg(verbose, "No records match this search request")
+      mssg(messages, "No records match this search request")
       if (fxn == "spatialsearch") { 
-        mssg(verbose, "Check signs on decimal longitude and latitude") 
+        mssg(messages, "Check signs on decimal longitude and latitude") 
       }
     } else {
       ress
@@ -33,7 +36,7 @@ mssg <- function(v, ...) if (v) message(...)
 
 get_terms <- function(){
   url <- "https://raw.githubusercontent.com/tdwg/dwc/master/downloads/SimpleDwCTermsList.txt"
-  termlist <- utils::read.table(text = content(GET(url), as = "text", encoding = "UTF-8"), stringsAsFactors = FALSE)
+  termlist <- utils::read.table(text = crul::HttpClient$new(url)$get()$parse("UTF-8"), stringsAsFactors = FALSE)
   # Strip embedded header from termlist and deal with upper vs. lower case in termlist vs. out$recs
   if (grep("term", tolower(termlist[1,1]))) termlist <- as.data.frame(termlist[-1,1], stringsAsFactors = FALSE)
   fullr <- as.data.frame(matrix(NA, 1, length(termlist[,1]))) # Create a full data frame to populate
@@ -41,16 +44,22 @@ get_terms <- function(){
   list(termlist = termlist, fullr = fullr)
 }
 
-vert_GET <- function(fxn="searchbyterm", args, limit = 1000, verbose = TRUE, ...){
+vert_GET <- function(fxn="searchbyterm", args, limit = 1000, messages = TRUE, 
+                     only_dwc = TRUE, callopts = list(), ...) {
   cursor <- NULL
   allres <- 0
   result <- list()
   i <- 0
+  cli <- crul::HttpClient$new(url = vurl(), opts = callopts)
   while (allres < limit) {
+    # increment iterator
     i <- i + 1
-    tt <- GET(vurl(), query = list(q = make_q(fxn, args, cursor, getlim(limit, allres))), ...)
-    stop_for_status(tt)
-    txt <- content(tt, "text", encoding = "UTF-8")
+  
+    # http  
+    tt <- cli$get('api/search', query = list(q = make_q(fxn, args, cursor, getlim(limit, allres))), ...)
+    tt$raise_for_status()
+    txt <- tt$parse("UTF-8")
+    
     out <- jsonlite::fromJSON(txt)
     avail <- out$matching_records
     cursor <- out$cursor
@@ -60,17 +69,19 @@ vert_GET <- function(fxn="searchbyterm", args, limit = 1000, verbose = TRUE, ...
   }
   df <- if (sum(sapply(result, NROW)) == 0) data.frame(NULL, stringsAsFactors = FALSE) else bind_rows(result)
   names(df) <- tolower(names(df))
-  res <- get_terms()
-  df <- merge(res$fullr, df, all = TRUE)[, tolower(res$termlist[,1]) ]
-  df <- df[ -NROW(df), ]
-  mssg(verbose, paste("\nLast Query URL: \"", tt$url, "\"", sep = ""))
-  mssg(verbose, paste("\nMatching records:", NROW(df), "returned,", avail, "available", sep = " "))
+  if (only_dwc) {
+    res <- get_terms()
+    df <- merge(res$fullr, df, all = TRUE)[, tolower(res$termlist[,1]) ]
+    df <- df[ -NROW(df), ]
+  }
+  mssg(messages, paste("\nLast Query URL: \"", tt$url, "\"", sep = ""))
+  mssg(messages, paste("\nMatching records:", NROW(df), "returned,", avail, "available", sep = " "))
   list(meta = make_meta(out), data = tbl_df(df))
 }
 
 make_q <- function(fxn, x, cursor = NULL, limit=1000){
   qry <- ""
-  if (fxn == "vertsearch") x <- paste0(unname(unlist(x)), collapse = " ")
+  if (fxn == "vertsearch") x <- strtrim(paste0(unname(unlist(x)), collapse = " "))
   if (fxn == "spatialsearch") x <- sprintf("distance(location,geopoint(%s,%s))<%s", x$lat, x$long, x$radius)
   # if query param present, remove named param
   if ("query" %in% names(x)) {
@@ -81,27 +92,27 @@ make_q <- function(fxn, x, cursor = NULL, limit=1000){
     if (!is.null(cursor)) {
       ff <- sprintf(
         '{"q":"%s","l":%s,"c":"%s"}', 
-        noc(gsub('\"|\\{|\\}', "", jsonlite::toJSON(x, auto_unbox = TRUE)), fxn), 
+        strtrim(noc(gsub('\"|\\{|\\}', "", jsonlite::toJSON(x, auto_unbox = TRUE)), fxn)), 
         limit, 
         cursor
       )
     } else {
       ff <- sprintf(
         '{"q":"%s","l":%s}', 
-        paste(
+        strtrim(paste(
           qry,
           noc(gsub('\"|\\{|\\}', "", jsonlite::toJSON(x, auto_unbox = TRUE)), fxn)
-        ),
+        )),
         limit
       )
     }
   } else {
     ff <- sprintf(
       '{"q":"%s"}',
-      paste(
+      strtrim(paste(
         qry,
         noc(gsub('\"|\\{|\\}', "", jsonlite::toJSON(x, auto_unbox = TRUE)), fxn)
-      )
+      ))
     )
   }
   
@@ -109,8 +120,8 @@ make_q <- function(fxn, x, cursor = NULL, limit=1000){
   gsub("year\\.[0-9]", "year", tmp)
 }
 
-vurl <- function() "http://api.vertnet-portal.appspot.com/api/search"
-vdurl <- function() "http://api.vertnet-portal.appspot.com/api/download"
+vurl <- function() "http://api.vertnet-portal.appspot.com"
+vdurl <- function() "http://api.vertnet-portal.appspot.com"
 
 make_meta <- function(x){
   tmp <- x[ !names(x) %in% "recs" ]
@@ -149,17 +160,18 @@ combyr <- function(x) {
     list(year = x)
   } 
 }
-
-checkfourpkg <- function(x) {
-  if (!requireNamespace(x, quietly = TRUE)) {
-    stop("Please install ", x, call. = FALSE)
-  } else {
-    invisible(TRUE)
-  }
-}
   
 pop <- function(x, nms) {
   x[!names(x) %in% nms]
 }
 
 rvc <- function(x) Filter(Negate(is.null), x)
+
+assert <- function(x, y) {
+  if (!is.null(x)) {
+    if (!class(x) %in% y) {
+      stop(deparse(substitute(x)), " must be of class ", 
+           paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
